@@ -63,7 +63,8 @@ sub parse {
   $charset ||= $self->charset;
   $body = $charset ? decode($charset, $body) // $body : $body;
   $source = $url || $file;
-  return Mojo::Feed->new(body => $body, source => $source);
+  my $feed = Mojo::Feed->new(body => $body, source => $source);
+  return ($feed->is_valid) ? $feed : undef;
 }
 
 sub load {
@@ -129,7 +130,7 @@ sub _find_feed_links {
 
     # call me crazy, but maybe this is just a feed served as HTML?
     unless (@feeds) {
-      if ($self->parse($res->body)->description) {
+      if ($self->parse($res->body, $res->content->charset)) {
         push @feeds, Mojo::URL->new($url)->to_abs;
       }
     }
@@ -258,6 +259,9 @@ objects)
 
 A minimalist liberal RSS/Atom parser, using Mojo::DOM queries.
 
+If the parsed object is not a feed (for example, the parser was given an HTML page),
+the method will return undef.
+
 =head2 parse_opml
 
   my @subscriptions = Mojo::Feed->parse_opml( 'mysubs.opml' );
